@@ -21,7 +21,7 @@ from  flashcam.stream_enhancer import Stream_Enhancer
 from flashcam import v4lc
 from flashcam.v4lc import set_gem, tune_histo
 
-from flashcam.mmapwr import mmread_n_clear
+from flashcam.mmapwr import mmread_n_clear, mmread
 
 import os
 import sys
@@ -87,6 +87,8 @@ class Camera(BaseCamera):
         """
         # i need these to be in globals() ----evaluate from web.py
         global substract_background,save_background
+        global mix_foreground,save_foreground
+
         global speedx, speedy, restart_translate, average
         global gamma_divide, gamma_multiply,gamma_setdef
         global gain_divide,gain_multiply,gain_setdef
@@ -120,6 +122,9 @@ class Camera(BaseCamera):
         # ------------------    to evaluate commands from web.py
         substract_background = False
         save_background = False
+        mix_foreground = False
+        save_foreground = False
+
         restart_translate = False
 
         gamma_divide = False
@@ -158,6 +163,9 @@ class Camera(BaseCamera):
                     print(f"!... monoskop.jpg not found {fullpath_fixed_image}")
                 time.sleep(1)
 
+
+        #=------------------------------------------- EXPO GAIN
+
         cc = v4lc.V4L2_CTL("/dev/video"+str(vidnum))
         capa = cc.get_capbilities()
 
@@ -273,35 +281,36 @@ class Camera(BaseCamera):
 
 
                     #------------------------------ BRUTAL ------------test exposure V4L
-                    if (BaseCamera.nframes % 100==0):
-                        cc = v4lc.V4L2_CTL("/dev/video"+str(vidnum))
-                        capa = cc.get_capbilities()
-                        #cc.refresh()
-                        exposure_absolute = 100
-                        expo_auto = 3
-                        expo_autodef = 3
+                    # if (BaseCamera.nframes % 100==0):
+                    #     cc = v4lc.V4L2_CTL("/dev/video"+str(vidnum))
+                    #     capa = cc.get_capbilities()
+                    #     #cc.refresh()
+                    #     exposure_absolute = 100
+                    #     expo_auto = 3
+                    #     expo_autodef = 3
 
 
-                        # stupid camera ZC0303 Webcam - parallel to exposure_auto
-                        if "exposure" in capa:
-                            exposure = cc.get_exposure()
+                    #     # stupid camera ZC0303 Webcam - parallel to exposure_auto
+                    #     if "exposure" in capa:
+                    #         exposure = cc.get_exposure()
 
-                        if "exposure_auto" in capa: # notauto? alway show _absolute
-                            expo_auto = cc.get_exposure_auto()
-                            expo_autodef = cc.getdef_exposure_auto()
-                            print(f"i...                   EXPOAUTO (inloop) == {expo_auto}/{expo_autodef}  [{BaseCamera.nframes%3}]; ",end="\r")
+                    #     if "exposure_auto" in capa: # notauto? alway show _absolute
+                    #         expo_auto = cc.get_exposure_auto()
+                    #         expo_autodef = cc.getdef_exposure_auto()
+                    #         print(f"i...                   EXPOAUTO (inloop) == {expo_auto}/{expo_autodef}  [{BaseCamera.nframes%3}]; ",end="\r")
 
-                        if "exposure_absolute" in capa:
-                            exposure_absolute = cc.get_exposure_absolute()
+                    #     if "exposure_absolute" in capa:
+                    #         exposure_absolute = cc.get_exposure_absolute()
 
 
-                        if "gain" in capa:
-                            gain = cc.get_gain()
-                            gaindef = cc.getdef_gain()
-                        if "gamma" in capa:
-                            gamma = cc.get_gamma()
-                            gammadef = cc.getdef_gamma()
-                    #--------------------------------------------------------------------------
+                    #     if "gain" in capa:
+                    #         gain = cc.get_gain()
+                    #         gaindef = cc.getdef_gain()
+                    #     if "gamma" in capa:
+                    #         gamma = cc.get_gamma()
+                    #         gammadef = cc.getdef_gamma()
+                    # #------------------------------------------------------------
+
 
                     #=========== BEFORE OTHER === Create final image ====
                     #=========== like ZOOM
@@ -353,15 +362,19 @@ class Camera(BaseCamera):
                     # ------------------------- commands comming from web.py----
 
                     expression,value = mmread_n_clear( )
-                    #print(f"i... expression == {expression}  value == {value}")
+                    if expression[:5] != "xxxxx":
+                        print(f"i...  *  EXPR: {expression} == {value}")
+                        print(f"i...  *  EXPR: {expression} == {value}")
+                        print(f"i...  *  EXPR: {expression} == {value}")
+                        print(f"i...  *  EXPR: {expression} == {value}")
                     # --- fixed_image
+
                     try:
                         globals()[expression] = eval(value)
                     except:
                         print("X... EXEC FAIL",expression,value)
 
 
-
                     if save_background:
                         print("D... HERE I SAVE save_background of mask")
                         print("D... HERE I SAVE save_background of mask")
@@ -375,6 +388,19 @@ class Camera(BaseCamera):
                         print("D... HERE I MUST DO subtraction of mask",speedx, speedy)
                         senh.subtract()
 
+
+                    if save_foreground:
+                        print("D... HERE I SAVE save_foreground ")
+                        print("D... HERE I SAVE save_foreground ")
+                        print("D... HERE I SAVE save_foreground ")
+                        senh.save_foreground()
+                        save_foreground = False  # ONE SHOT
+
+                    if mix_foreground:
+                        print("D... HERE I mix the foreground")
+                        senh.mix()
+
+
                     # - compensate for speed of the sky
                     if ((speedx!=0) or (speedy!=0)) and ((abs(speedx)<1) and (abs(speedy)<1)):
                         print(f"speed translate {speedx} {speedy}")
