@@ -1015,8 +1015,18 @@ def display2(videodev, save = False,
                     if (key == ord('c')):
                         if cross is None:
                             cross = [ 0,0 ]
-                            print(f"c PRESSED! - cross = {cross}")
+                            if os.path.exists( os.path.expanduser('~/.flashcam_unicross.txt') ):
+                                try:
+                                    with open( os.path.expanduser('~/.flashcam_unicross.txt') ) as f:
+                                        cr = f.readlines()
+                                        cross = [ int(cr[0]) ,  int(cr[1])  ]
+                                except:
+                                    print("X... problem with ~/.flashcam_unicross.txt")
+                            print(f"c PRESSED! - cross = {cross} ON")
                         else:
+                            print(f"c PRESSED! - cross = {cross} OFF; saving  ~/.flashcam_unicross")
+                            with open( os.path.expanduser('~/.flashcam_unicross.txt') ,"w") as f:
+                                f.write( f"{cross[0]}\n{cross[1]}\n" )
                             cross = None
                 if not(cross is None):
                     if (not frame is None) and (rpi_name!="") and (key == ord('h')): #<
